---
title: <span class="badge object-type-scalar"></span> TerabytesPerSecond
---
# <span class="badge object-type-scalar"></span> TerabytesPerSecond

Data rate: terabytes/sec

## Definition

```python
# Data rate: terabytes/sec
TerabytesPerSecond: typing.Literal["TBs"] = "TBs"
```
